@@ -66,9 +66,10 @@ func (flags *Flags) RenderIf(config *config.Config) {
 		version := "dev"
 		date := "now"
 		for _, setting := range info.Settings {
-			if setting.Key == "vcs.revision" {
+			switch setting.Key {
+			case "vcs.revision":
 				version = setting.Value
-			} else if setting.Key == "vcs.time" {
+			case "vcs.time":
 				date = setting.Value
 			}
 		}
