@@ -64,7 +64,7 @@ func (widget *Widget) Refresh() {
 func (widget *Widget) content() (string, string, bool) {
 	title := fmt.Sprintf(
 		"[%s]%s[white]",
-		widget.settings.Colors.TextTheme.Title,
+		widget.settings.Colors.Title,
 		widget.CurrentSource(),
 	)
 
