@@ -10,7 +10,7 @@ import (
 )
 
 func (widget *Widget) display() {
-	widget.ScrollableWidget.Redraw(widget.content)
+	widget.Redraw(widget.content)
 }
 
 func (widget *Widget) content() (string, string, bool) {
