@@ -24,10 +24,10 @@ func NewTextWidget(tviewApp *tview.Application, redrawChan chan bool, pages *tvi
 	}
 
 	widget.View = widget.createView(widget.bordered)
-	widget.View.SetInputCapture(widget.KeyboardWidget.InputCapture)
+	widget.View.SetInputCapture(widget.InputCapture)
 
-	widget.Base.SetView(widget.View)
-	widget.Base.helpTextFunc = widget.KeyboardWidget.HelpText
+	widget.SetView(widget.View)
+	widget.helpTextFunc = widget.HelpText
 
 	return widget
 }
@@ -56,12 +56,12 @@ func (widget *TextWidget) Redraw(data func() (string, string, bool)) {
 func (widget *TextWidget) createView(bordered bool) *tview.TextView {
 	view := tview.NewTextView()
 
-	view.SetBackgroundColor(wtf.ColorFor(widget.commonSettings.Colors.WidgetTheme.Background))
+	view.SetBackgroundColor(wtf.ColorFor(widget.commonSettings.Colors.Background))
 	view.SetBorder(bordered)
 	view.SetBorderColor(wtf.ColorFor(widget.BorderColor()))
 	view.SetDynamicColors(true)
-	view.SetTextColor(wtf.ColorFor(widget.commonSettings.Colors.TextTheme.Text))
-	view.SetTitleColor(wtf.ColorFor(widget.commonSettings.Colors.TextTheme.Title))
+	view.SetTextColor(wtf.ColorFor(widget.commonSettings.Colors.Text))
+	view.SetTitleColor(wtf.ColorFor(widget.commonSettings.Colors.Title))
 	view.SetWrap(false)
 
 	return view
